3.29.6 (2021-10-07)
===================
🎉 New features
---------------

- Allow authentication on SMTP for outgoing emails. This feature was present in 3.28, but got lost during merge.

3.29
====

🎉 New features
---------------

- we started to reorganize the documentation, in particular the index, this work will continue with the next releases. Thus, some chapters are still missing
- ext/markdown: add urlize extension to auto link url in markdown documents

👷 Bug fixes
------------

- .gitlab-ci.yaml.tmpl should be named .gitlab-ci.yml.tmpl for heptapod

Documentation
-------------

- Change data model link to use the definition from YAMS
- reorganize the TOC
- fix a few dead links
- add explanation on site_cubicweb.py
- update cube layout documentation
- add more explanations to what is a cube
- pooler: bad option name for the connections pooler
- Change data model link to use the definition from YAMS

🤖 Continuous integration
-------------------------

- build the documentation on gitlab pages

🤷 Various changes
------------------

- DeprecatedWarning: [logilab.common.deprecation] moved has been renamed and is deprecated, uses callable_moved instead
- add pipeline badge and shields with stats from pypi & docker
